@@ -1,5 +1,6 @@
 import datetime
 import decimal
+import time
 import itertools
 import iso8601
 import pprint
@@ -1091,8 +1092,8 @@ class DateTime(SchemaType):
     """
     err_template =  _('Invalid date')
 
-    def __init__(self, default_tzinfo=None):
-        if default_tzinfo is None:
+    def __init__(self, default_tzinfo=_marker):
+        if default_tzinfo is _marker:
             default_tzinfo = iso8601.iso8601.Utc()
         self.default_tzinfo = default_tzinfo
         
@@ -1118,7 +1119,8 @@ class DateTime(SchemaType):
             return null
         
         try:
-            result = iso8601.parse_date(cstruct)
+            result = iso8601.parse_date(
+                cstruct, default_timezone=self.default_tzinfo)
         except (iso8601.ParseError, TypeError), e:
             try:
                 year, month, day = map(int, cstruct.split('-', 2))
@@ -1203,6 +1205,87 @@ class Date(SchemaType):
                               )
         return result
 
+class Time(SchemaType):
+    """ A type representing a Python ``datetime.time`` object.
+
+    .. note:: This type is new as of Colander 0.9.3.
+
+    This type serializes python ``datetime.time`` objects to a
+    `ISO8601 <http://en.wikipedia.org/wiki/ISO_8601>`_ string format.
+    The format includes the date only.
+
+    The constructor accepts no arguments.
+
+    You can adjust the error message reported by this class by
+    changing its ``err_template`` attribute in a subclass on an
+    instance of this class.  By default, the ``err_template``
+    attribute is the string ``Invalid date``.  This string is used as
+    the interpolation subject of a dictionary composed of ``val`` and
+    ``err``.  ``val`` and ``err`` are the unvalidatable value and the
+    exception caused trying to convert the value, respectively. These
+    may be used in an overridden err_template as ``${val}`` and
+    ``${err}`` respectively as necessary, e.g. ``_('${val} cannot be
+    parsed as an iso8601 date: ${err}')``.
+
+    For convenience, this type is also willing to coerce
+    ``datetime.datetime`` objects to a time-only ISO string
+    representation during serialization.  It does so by stripping off
+    any date information, converting the ``datetime.datetime`` into a
+    time before serializing.
+
+    Likewise, for convenience, this type is also willing to coerce ISO
+    representations that contain time info into a ``datetime.time``
+    object during deserialization.  It does so by throwing away any
+    date information related to the serialized value during
+    deserialization.
+
+    If the :attr:`colander.null` value is passed to the serialize
+    method of this class, the :attr:`colander.null` value will be
+    returned.
+
+    The subnodes of the :class:`colander.SchemaNode` that wraps
+    this type are ignored.
+    """
+
+    err_template =  _('Invalid time')
+
+    def serialize(self, node, appstruct):
+        if appstruct is null:
+            return null
+
+        if isinstance(appstruct, datetime.datetime):
+            appstruct = appstruct.time()
+
+        if not isinstance(appstruct, datetime.time):
+            raise Invalid(node,
+                          _('"${val}" is not a time object',
+                            mapping={'val':appstruct})
+                          )
+
+        return appstruct.isoformat().split('.')[0]
+
+    def deserialize(self, node, cstruct):
+        if not cstruct:
+            return null
+        try:
+            result = iso8601.parse_date(cstruct)
+            result = result.time()
+        except (iso8601.ParseError, TypeError):
+            try:
+                result = timeparse(cstruct, '%H:%M:%S')
+            except ValueError:
+                try:
+                    result = timeparse(cstruct, '%H:%M')
+                except Exception, e:
+                    raise Invalid(node,
+                                  _(self.err_template,
+                                    mapping={'val':cstruct, 'err':e})
+                                  )
+        return result
+
+def timeparse(t, format):
+    return datetime.datetime(*time.strptime(t, format)[0:6]).time()
+
 class SchemaNode(object):
     """
     Fundamental building block of schemas.
@@ -1230,6 +1313,10 @@ class SchemaNode(object):
       'required'.  When ``missing`` is :attr:`colander.required`, the
       ``required`` computed attribute will be ``True``.
 
+    - ``preparer``: Optional preparer for this node.  It should be
+      an object that implements the
+      :class:`colander.interfaces.Preparer` interface.
+
     - ``validator``: Optional validator for this node.  It should be
       an object that implements the
       :class:`colander.interfaces.Validator` interface.
@@ -1274,6 +1361,7 @@ class SchemaNode(object):
         
     def __init__(self, typ, *children, **kw):
         self.typ = typ
+        self.preparer = kw.pop('preparer', None)
         self.validator = kw.pop('validator', None)
         self.default = kw.pop('default', null)
         self.missing = kw.pop('missing', required)
@@ -1337,13 +1425,14 @@ class SchemaNode(object):
 
     def deserialize(self, cstruct=null):
         """ Deserialize the :term:`cstruct` into an :term:`appstruct` based
-        on the schema, and return the deserialized, then validate the
-        resulting appstruct.  The ``cstruct`` value is deserialized into an
+        on the schema, run this :term:`appstruct` through the
+        preparer, if one is present, then validate the
+        prepared appstruct.  The ``cstruct`` value is deserialized into an
         ``appstruct`` unconditionally.
 
-        If ``appstruct`` returned by type deserialization is the value
-        :attr:`colander.null`, do something special before attempting
-        validation:
+        If ``appstruct`` returned by type deserialization and
+        preparation is the value :attr:`colander.null`, do something
+        special before attempting validation:
 
         - If the ``missing`` attribute of this node has been set explicitly,
           return its value.  No validation of this value is performed; it is
@@ -1360,6 +1449,9 @@ class SchemaNode(object):
         """
         appstruct = self.typ.deserialize(self, cstruct)
 
+        if self.preparer is not None:
+            appstruct = self.preparer(appstruct)
+            
         if appstruct is null:
             appstruct = self.missing
             if appstruct is required:
