@@ -1258,6 +1258,13 @@ class TestDateTime(unittest.TestCase):
         expected = dt.replace(tzinfo=typ.default_tzinfo).isoformat()
         self.assertEqual(result, expected)
 
+    def test_serialize_with_none_tzinfo_naive_datetime(self):
+        typ = self._makeOne(default_tzinfo=None)
+        node = DummySchemaNode(None)
+        dt = self._dt()
+        result = typ.serialize(node, dt)
+        self.assertEqual(result, dt.isoformat())
+
     def test_serialize_with_tzware_datetime(self):
         import iso8601
         typ = self._makeOne()
@@ -1312,7 +1319,26 @@ class TestDateTime(unittest.TestCase):
         node = DummySchemaNode(None)
         result = typ.deserialize(node, iso)
         self.assertEqual(result.isoformat(), iso)
-        
+
+    def test_deserialize_naive_with_default_tzinfo(self):
+        import iso8601
+        tzinfo = iso8601.iso8601.FixedOffset(1, 0, 'myname')
+        typ = self._makeOne(default_tzinfo=tzinfo)
+        dt = self._dt()
+        dt_with_tz = dt.replace(tzinfo=tzinfo)
+        iso = dt.isoformat()
+        node = DummySchemaNode(None)
+        result = typ.deserialize(node, iso)
+        self.assertEqual(result.isoformat(), dt_with_tz.isoformat())
+
+    def test_deserialize_none_tzinfo(self):
+        typ = self._makeOne(default_tzinfo=None)
+        dt = self._dt()
+        iso = dt.isoformat()
+        node = DummySchemaNode(None)
+        result = typ.deserialize(node, iso)
+        self.assertEqual(result.isoformat(), dt.isoformat())
+
 class TestDate(unittest.TestCase):
     def _makeOne(self, *arg, **kw):
         from colander import Date
@@ -1398,6 +1424,106 @@ class TestDate(unittest.TestCase):
         result = typ.deserialize(node, iso)
         self.assertEqual(result.isoformat(), dt.date().isoformat())
 
+class TestTime(unittest.TestCase):
+    def _makeOne(self, *arg, **kw):
+        from colander import Time
+        return Time(*arg, **kw)
+
+    def _dt(self):
+        import datetime
+        return datetime.datetime(2010, 4, 26, 10, 48)
+
+    def _now(self):
+        import datetime
+        return datetime.datetime.now().time()
+
+    def test_serialize_null(self):
+        import colander
+        val = colander.null
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.serialize(node, val)
+        self.assertEqual(result, colander.null)
+
+    def test_serialize_with_garbage(self):
+        typ = self._makeOne()
+        node = DummySchemaNode(None)
+        e = invalid_exc(typ.serialize, node, 'garbage')
+        self.assertEqual(e.msg.interpolate(), '"garbage" is not a time object')
+
+    def test_serialize_with_time(self):
+        typ = self._makeOne()
+        time = self._now()
+        node = DummySchemaNode(None)
+        result = typ.serialize(node, time)
+        expected = time.isoformat().split('.')[0]
+        self.assertEqual(result, expected)
+
+    def test_serialize_with_datetime(self):
+        typ = self._makeOne()
+        dt = self._dt()
+        node = DummySchemaNode(None)
+        result = typ.serialize(node, dt)
+        expected = dt.time().isoformat().split('.')[0]
+        self.assertEqual(result, expected)
+
+    def test_deserialize_invalid_ParseError(self):
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        e = invalid_exc(typ.deserialize, node, 'garbage')
+        self.failUnless('Invalid' in e.msg)
+
+    def test_deserialize_three_digit_string(self):
+        import datetime
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.deserialize(node, '11:00:11')
+        self.assertEqual(result, datetime.time(11, 0, 11))
+
+    def test_deserialize_two_digit_string(self):
+        import datetime
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.deserialize(node, '11:00')
+        self.assertEqual(result, datetime.time(11, 0))
+
+    def test_deserialize_null(self):
+        import colander
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.deserialize(node, colander.null)
+        self.assertEqual(result, colander.null)
+
+    def test_deserialize_empty(self):
+        import colander
+        node = DummySchemaNode(None)
+        typ = self._makeOne()
+        result = typ.deserialize(node, '')
+        self.assertEqual(result, colander.null)
+
+    def test_deserialize_missing_seconds(self):
+        import datetime
+        typ = self._makeOne()
+        node = DummySchemaNode(None)
+        result = typ.deserialize(node, '10:12')
+        self.assertEqual(result, datetime.time(10, 12))
+
+    def test_deserialize_success_time(self):
+        import datetime
+        typ = self._makeOne()
+        node = DummySchemaNode(None)
+        result = typ.deserialize(node, '10:12:13')
+        self.assertEqual(result, datetime.time(10, 12, 13))
+
+    def test_deserialize_success_datetime(self):
+        dt = self._dt()
+        typ = self._makeOne()
+        iso = dt.isoformat()
+        node = DummySchemaNode(None)
+        result = typ.deserialize(node, iso)
+        self.assertEqual(result.isoformat(),
+                dt.time().isoformat().split('.')[0])
+
 class TestSchemaNode(unittest.TestCase):
     def _makeOne(self, *arg, **kw):
         from colander import SchemaNode
@@ -1437,6 +1563,14 @@ class TestSchemaNode(unittest.TestCase):
         node = self._makeOne(None, 0, widget='abc')
         self.assertEqual(node.widget, 'abc')
 
+    def test_ctor_with_preparer(self):
+        node = self._makeOne(None, 0, preparer='abc')
+        self.assertEqual(node.preparer, 'abc')
+
+    def test_ctor_without_preparer(self):
+        node = self._makeOne(None, 0)
+        self.assertEqual(node.preparer, None)
+
     def test_ctor_with_unknown_kwarg(self):
         node = self._makeOne(None, 0, foo=1)
         self.assertEqual(node.foo, 1)
@@ -1460,6 +1594,29 @@ class TestSchemaNode(unittest.TestCase):
         result = node.deserialize(1)
         self.assertEqual(result, 1)
 
+    def test_deserialize_with_preparer(self):
+        from colander import Invalid
+        typ = DummyType()
+        def preparer(value):
+            return 'prepared_'+value
+        def validator(node, value):
+            if not value.startswith('prepared'):
+                raise Invalid(node, 'not prepared') # pragma: no cover
+        node = self._makeOne(typ,
+                             preparer=preparer,
+                             validator=validator)
+        self.assertEqual(node.deserialize('value'),
+                         'prepared_value')
+
+    def test_deserialize_preparer_before_missing_check(self):
+        from colander import null
+        typ = DummyType()
+        def preparer(value):
+            return null
+        node = self._makeOne(typ,preparer=preparer)
+        e = invalid_exc(node.deserialize, 1)
+        self.assertEqual(e.msg, 'Required')
+
     def test_deserialize_with_validator(self):
         typ = DummyType()
         validator = DummyValidator(msg='Wrong')
