@@ -52,7 +52,7 @@ copyright = '2010, Agendaless Consulting <pylons-discuss@googlegroups.com>'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '0.9.2'
+version = '0.9.3'
 # The full version, including alpha/beta/rc tags.
 release = version
 
@@ -63,7 +63,7 @@ release = version
 today_fmt = '%B %d, %Y'
 
 # List of documents that shouldn't be included in the build.
-#unused_docs = []
+unused_docs = ['_themes/README']
 
 # List of directories, relative to source directories, that shouldn't be
 # searched for source files.
